<?php

namespace Drupal\Tests\l10n_tools\Functional;

/**
 * TransCleanupFormUITest.
 *
 * @group l10n_tools
 */
class L10nToolsFormUITest extends L10nToolsFunctionalTestBase
{

  /**
   * Tests if getEqualTranslations catches an exception and returns false
   * @test
   * @return void
   */
  public function getEqualTranslationsTest()
  {
    $equalNoFilter = $this->queryhelper->getEqualTranslations();
    $equalCustom = $this->queryhelper->getEqualTranslations('0');
    $equalNoCustom = $this->queryhelper->getEqualTranslations('1');

    $this->assertNotFalse($equalNoFilter);
    $this->assertNotFalse($equalCustom);
    $this->assertNotFalse($equalNoCustom);
  }

  //TODO: See if the ajax tables can be accessed through functional tests, otherwise use nightwatch.js for ajax checking

  /**
   * Tests to see if the l10n_tools url and route exists
   *
   * @return void
   */
  public function testURLexists(){
    //does the L10n Tools Site exist
    $this->drupalGet('admin/config/regional/l10n_tools');
  }

  public function testRouteExists(){
    $route_provider = \Drupal::service('l10n_tools.form');
    $exists = count($route_provider->getRoutesByNames(['l10n_tools.form'])) === 1;
    $this->assertEqual($exists, TRUE);
  }

  /**
   * Tests to see if the "Equal translations" section with the select option
   * "Only user customized translations" works properly
   *
   * @return void
   */
  public function testEqualOnlyUserCustomized()
  {
    // Tests Show all equal translations
    // Create 2 Equal Translations customized=1
    $this->createTranslation('Test1', 'Test1');
    $this->createTranslation('Test2', 'Test2');
    // Go to l10n_tools page
    $this->drupalGet('admin/config/regional/l10n_tools');
    // See if "Filter equal translations exists"
    $this->assertSession()->selectExists('filterCustomized');
    // Select Only user customized translations
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', '1');
    // Press show all equal translations
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    $this->assertSession()->pageTextContains('Test1');
    $this->assertSession()->pageTextContains('Test2');
    // If equal translations are shown, delete them with clear translations button
    $this->getSession()->getPage()->pressButton('Clear translations of all listed equal translations');
    // Select Only user customized translations again after clear
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', '1');
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    // Press show, are they deleted? (look for "no translations found" in table)
    $this->assertSession()->pageTextContains('No translations found!');
  }

  /**
   * Tests to see if the "Equal translations" section with the select option
   * "Only default / imported translations" works properly
   *
   * @return void
   */
  public function testEqualOnlyDefaultCustomized()
  {
    // Tests Show all equal translations
    // Create 2 Equal Translations customized=0
    $this->createTranslation('Test1', 'Test1', FALSE);
    $this->createTranslation('Test2', 'Test2', FALSE);
    // Go to l10n_tools page
    $this->drupalGet('admin/config/regional/l10n_tools');
    // Select Only user default translations
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', '0');
    // Press show all equal translations
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    $this->assertSession()->pageTextContains('Test1');
    $this->assertSession()->pageTextContains('Test2');
    // If equal translations are shown, delete them with clear translations button
    $this->getSession()->getPage()->pressButton('Clear translations of all listed equal translations');
    // Select Only default translations again after clear
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', '0');
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    // Press show, are they deleted? (look for "no translations found" in table)
    $this->assertSession()->pageTextContains('No translations found!');
  }

  /**
   * Tests to see if the "Equal translations" section with the select option
   * "Both user and user customized translations" works properly
   *
   * @return void
   */
  public function testEqualBothCustomized()
  {
    // Tests Show all equal translations
    // Create 2 Equal Translations customized=0
    $this->createTranslation('Test1', 'Test1', FALSE);
    $this->createTranslation('Test2', 'Test2', FALSE);
    // Create 1 Equal Translation customized=1
    $this->createTranslation('Test3', 'Test3');
    // Go to l10n_tools page
    $this->drupalGet('admin/config/regional/l10n_tools');
    // Select Only user default translations
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', NULL);
    // Press show all equal translations
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    $this->assertSession()->pageTextContains('Test1');
    $this->assertSession()->pageTextContains('Test2');
    $this->assertSession()->pageTextContains('Test3');
    // If equal translations are shown, delete them with clear translations button
    $this->getSession()->getPage()->pressButton('Clear translations of all listed equal translations');
    // Select Only default translations again after clear
    $this->getSession()->getPage()->selectFieldOption('filterCustomized', NULL);
    $this->getSession()->getPage()->pressButton('Show all equal translations');
    // Press show, are they deleted? (look for "no translations found" in table)
    $this->assertSession()->pageTextContains('No translations found!');
  }

  /**
   * Tests to see if the "Orphan / Untranslated translations" section works properly
   *
   * @return void
   */
  public function testOrphanUntranslatedTranslations()
  {
    // Tests show all orphan translations
    // Create 2 Orphan Translations
    $this->createTranslation('Test1', '');
    $this->createTranslation('Test2', '');
    // Go to l10n_tools Site
    $this->drupalGet('admin/config/regional/l10n_tools');
    // Press show all orphan translations, are the entries shown?
    $this->getSession()->getPage()->pressButton('Show all orphan / untranslated translations');
    $this->assertSession()->pageTextContains('Test1');
    $this->assertSession()->pageTextContains('Test2');
    // If orphan translations are shown, delete them with delete all listed button
    $this->getSession()->getPage()->pressButton('Delete all listed orphan / untranslated translations');
    $this->getSession()->getPage()->pressButton('Show all orphan / untranslated translations');
    // Press show, are they deleted? (look for "no translations found" in table)
    $this->assertSession()->pageTextContains('No translations found!');
  }

  /**
   * Tests to see if the "Reset translation status" section works properly
   *
   * @return void
   */
  public function testResetTranslationStatus()
  {
    // Press "Reset translation status"
    $this->drupalGet('admin/config/regional/l10n_tools');
    $this->getSession()->getPage()->pressButton('Reset translation status');
    // Is the status message shown?
    $this->assertSession()->pageTextContains('The locale_file timestamp and last checked date for all projects have been reset, 0 locale.translation_status entries removed.');
    // If yes, see if the "update translations" Link works
    $this->getSession()->getPage()->clickLink('update translations');
    //TODO:
    // Are all the key_values deleted, where collection = locale.translation_status?
    // In locale_file, are timestamp and last_checked 0?
    // Is locale.translation_last_checked 0?

    //Check if the "Check available translation updates manually" Link works
    $this->getSession()->getPage()->clickLink('Check available translation updates manually');
  }
}
