<?php

namespace Drupal\Tests\l10n_tools\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\locale\SourceString;
/**
 * This class provides methods specifically for testing the TransCleanup UI.
 *
 * @group l10n_tools
 */
abstract class L10nToolsFunctionalTestBase extends BrowserTestBase
{

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'l10n_tools',
    'locale',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Permissions for the admin user.
   *
   * @var array
   */
  protected $adminPermissions = [
    'access l10n_tools form',
  ];

  /**
   * A user with administrative permissions.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * The service under test.
   *
   * @var \Drupal\l10n_tools\QueryHelper
   */
  protected $queryhelper;

  /**
   * {@inheritdoc}
   */
  public function setUp()
  {
    parent::setUp(); //gibt error, aber sonst Container error

    // Create an admin user.
    $this->adminUser = $this->drupalCreateUser($this->adminPermissions);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * {@inheritdoc}
   */
  public function tearDown()
  {
    parent::tearDown();
    // Delete admin user.
    $this->adminUser->delete();
  }

  /**
   * Creates custom translations for testing
   *
   * @param string $sourcename
   *    The name of the source string
   * @param string $translationname
   *    The name of the translation of the source string
   * @param boolean $customized
   *    Wheter or not the translation should be listed as customized
   *
   * @return array|FALSE Returns the equal translations list.
   */
  protected function createTranslation($sourcename, $translationname, $customized = TRUE)
  {
    $storage = \Drupal::service('locale.storage');
    $string = new SourceString();
    $string->setString($sourcename);
    $string->setStorage($storage);
    $string->save();
    $translation = $storage->createTranslation([
    'lid' => $string->lid,
    'language' => 'de',
    'translation' => $translationname,
    ]);
    if ($customized === TRUE) {
      $translation->setCustomized();
    }
    $translation->save();
  }

}
