<?php

namespace Drupal\Tests\l10n_tools\Kernel;

use Symfony\Component\Routing\Exception\InvalidParameterException;

/**
 * L10nToolsQueryTest.
 *
 * @group l10n_tools
 */
class L10nToolsQueryTest extends L10nToolsKernelTestBase
{

  /**
   * Tests if getEqualTranslations catches an exception and returns false
   * @test
   * @return void
   */
  public function getEqualTranslationsTest()
  {
    $equalNoFilter = $this->queryhelper->getEqualTranslations();
    $equalCustom = $this->queryhelper->getEqualTranslations('0');
    $equalNoCustom = $this->queryhelper->getEqualTranslations('1');

    $this->assertNotFalse($equalNoFilter);
    $this->assertNotFalse($equalCustom);
    $this->assertNotFalse($equalNoCustom);
  }

  /**
   * Tests if a wrong parameter in getEqualTranslations throws an Exception
   * @test
   * @return void
   */
  public function getEqualWrongParameterTest()
  {
    $this->queryhelper->getEqualTranslations('Test');
    $this->expectException(InvalidParameterException::class);
  }

  /**
   * Tests if deleteEqualTranslations catches an exception and returns false
   * @test
   * @return void
   */
  public function deleteEqualTranslationsTest()
  {
    $equalNoFilter = $this->queryhelper->deleteEqualTranslations();
    $equalCustom = $this->queryhelper->deleteEqualTranslations('0');
    $equalNoCustom = $this->queryhelper->deleteEqualTranslations('1');

    $this->assertNotFalse($equalNoFilter);
    $this->assertNotFalse($equalCustom);
    $this->assertNotFalse($equalNoCustom);
  }

  /**
   * Tests if getOrphanTranslations catches an exception and returns false
   * @test
   * @return void
   */
  public function getOrphanTranslationsTest()
  {
    $orphan = $this->queryhelper->getOrphanTranslations();
    $this->assertNotFalse($orphan);
  }

  /**
   * Tests if deleteOrphanTranslations catches an exception and returns false
   * @test
   * @return void
   */
  public function deleteOrphanTranslationsTest()
  {
    $orphan = $this->queryhelper->deleteOrphanTranslations();
    $this->assertNotFalse($orphan);
  }

  /**
   * Tests if deleteCurrentTranslationStatus catches an exception and returns false
   * @test
   * @return void
   */
  public function deleteCurrentTranslationStatusTest()
  {
    $status = $this->queryhelper->deleteCurrentTranslationStatus();
    $this->assertNotFalse($status); //TODO: See if NULL counts as false in this method
  }

  /**
   * Tests if resetDateTimestamp catches an exception and returns false
   * @test
   * @return void
   */
  public function resetDateTimestampTest()
  {
    $status = $this->queryhelper->resetDateTimestamp();
    $this->assertNotFalse($status); //TODO: See if NULL counts as false in this method
  }

  /**
   * Tests if resetTranslationStatus catches an exception and returns false
   * @test
   * @return void
   */
  public function resetTranslationStatusTest()
  {
    $status = $this->queryhelper->resetTranslationStatus();
    $this->assertNotFalse($status); //TODO: See if NULL counts as false in this method
  }
}
